@@ -1,9 +1,6 @@
 use {
-    solana_runtime::{
-        bank::{Builtin, Builtins},
-        builtins::ActivationType,
-    },
-    solana_sdk::{feature_set, pubkey::Pubkey},
+    solana_runtime::builtins::{ActivationType, Builtin, Builtins},
+    solana_sdk::pubkey::Pubkey,
 };
 
 macro_rules! to_builtin {
@@ -32,25 +29,22 @@ fn genesis_builtins(bpf_jit: bool) -> Vec<Builtin> {
         } else {
             to_builtin!(solana_bpf_loader_program!())
         },
-    ]
-}
-
-/// Builtin programs activated dynamically by feature
-fn feature_builtins(bpf_jit: bool) -> Vec<(Builtin, Pubkey, ActivationType)> {
-    vec![(
         if bpf_jit {
             to_builtin!(solana_bpf_loader_upgradeable_program_with_jit!())
         } else {
             to_builtin!(solana_bpf_loader_upgradeable_program!())
         },
-        feature_set::bpf_loader_upgradeable_program::id(),
-        ActivationType::NewProgram,
-    )]
+    ]
+}
+
+/// Builtin programs activated dynamically by feature
+fn feature_builtins() -> Vec<(Builtin, Pubkey, ActivationType)> {
+    vec![]
 }
 
 pub(crate) fn get(bpf_jit: bool) -> Builtins {
     Builtins {
         genesis_builtins: genesis_builtins(bpf_jit),
-        feature_builtins: feature_builtins(bpf_jit),
+        feature_builtins: feature_builtins(),
     }
 }
